@@ -137,7 +137,7 @@ searchplos <- function(q = NULL, fl = 'id', fq = NULL, sort = NULL, start = 0,
     return(list(meta = meta, data = jsonout))
 	} else {
 	  byby <- 500
-	  getvecs <- seq(from = 1, to = getnumrecords, by = byby)
+	  getvecs <- seq(from = 0, to = getnumrecords - 1, by = byby)
 	  lastnum <- as.numeric(strextract(getnumrecords, "[0-9]{3}$"))
 	  if (lastnum == 0)
 	    lastnum <- byby
@@ -148,13 +148,13 @@ searchplos <- function(q = NULL, fl = 'id', fq = NULL, sort = NULL, start = 0,
 	  }
 	  getrows <- c(rep(byby, length(getvecs) - 1), lastnum)
 	  out <- list()
-	  message("Looping - printing progress ...")
 	  for (i in seq_along(getvecs)) {
 	    args$start <- getvecs[i]
 	    args$rows <- getrows[i]
 	    if (length(args) == 0) args <- NULL
 	    jsonout <- suppressMessages(conn_plos$search(
-	      params = ploscompact(list(q = args$q, fl = args$fl, fq = args$fq,
+	      params = ploscompact(list(q = args$q, fl = args$fl, 
+        fq = args[names(args) == "fq"],
 	      sort = args$sort,
 	      rows = args$rows, start = args$start,
 	      wt = "json")), minOptimizedRows = FALSE, callopts = callopts, ...
